@@ -217,7 +217,7 @@ class Users(_defaults_.Defaults):
 			return dev0s.response.error(self.__traceback__(function="update")+" Define one of the following parameters [email, username].")
 
 		# load.
-		response = self.get(email=email)
+		response = self.get(email=email, username=username)
 		if response.error != None: return response
 		user = response["user"]
 
@@ -1270,6 +1270,8 @@ class Users(_defaults_.Defaults):
 		except Exception as e:
 			raise ValueError(f"Unable retrieve the username of email [{email}], error: {e}.")
 	def __correct_username_email__(self, username, email):
+		if username in ["None", "null", "NaN"]: username = None
+		if email in ["None", "null", "NaN"]: email = None
 		if email in [None, username] and (username != None and "@" in username): 
 			email = username 
 			username = None
